classdef planets
    %all properties of system
    %   being computed here ...
    
    properties
        m
        theta
        G
        u0
        v0
        T
        M
        F
        L
        Tend
        tEnd
    end
    
    methods
        function obj = planets(data)
            %initialize
            %   class
            SIunits = containers.Map;
            SIunits('km')         =1000;
            SIunits('kg')         =1;
            SIunits('km/s')       =1000;
            SIunits('j')          =60*60*24*365;
            SIunits('m^3/kg/s^2') =1;
            
            obj.m(1) = data({'m[1]'},:).number*SIunits(data({'m[1]'},:).unit{1});
            obj.m(2) = data({'m[2]'},:).number*SIunits(data({'m[2]'},:).unit{1});
            obj.m(3) = data({'m[3]'},:).number*SIunits(data({'m[3]'},:).unit{1});
            
            obj.G    = data({'G'   },:).number*SIunits(data({'G'   },:).unit{1});
            obj.L    = data({'L'   },:).number*SIunits(data({'L'   },:).unit{1});
            
            % initial values
            obj.u0(1,1)= data({'u[1,x](0)'},:).number*SIunits(data({'u[1,x](0)'},:).unit{1});
            obj.u0(1,2)= data({'u[1,y](0)'},:).number*SIunits(data({'u[1,y](0)'},:).unit{1});
            obj.u0(1,3)= data({'u[1,z](0)'},:).number*SIunits(data({'u[1,z](0)'},:).unit{1});
            obj.u0(2,1)= data({'u[2,x](0)'},:).number*SIunits(data({'u[2,x](0)'},:).unit{1});
            obj.u0(2,2)= data({'u[2,y](0)'},:).number*SIunits(data({'u[2,y](0)'},:).unit{1});
            obj.u0(2,3)= data({'u[2,z](0)'},:).number*SIunits(data({'u[2,z](0)'},:).unit{1});
            obj.u0(3,1)= data({'u[3,x](0)'},:).number*SIunits(data({'u[3,x](0)'},:).unit{1});
            obj.u0(3,2)= data({'u[3,y](0)'},:).number*SIunits(data({'u[3,y](0)'},:).unit{1});
            obj.u0(3,3)= data({'u[3,z](0)'},:).number*SIunits(data({'u[3,z](0)'},:).unit{1});
            
            obj.v0(1,1)= data({'v[1,x](0)'},:).number*SIunits(data({'v[1,x](0)'},:).unit{1});
            obj.v0(1,2)= data({'v[1,y](0)'},:).number*SIunits(data({'v[1,y](0)'},:).unit{1});
            obj.v0(1,3)= data({'v[1,z](0)'},:).number*SIunits(data({'v[1,z](0)'},:).unit{1});
            obj.v0(2,1)= data({'v[2,x](0)'},:).number*SIunits(data({'v[2,x](0)'},:).unit{1});
            obj.v0(2,2)= data({'v[2,y](0)'},:).number*SIunits(data({'v[2,y](0)'},:).unit{1});
            obj.v0(2,3)= data({'v[2,z](0)'},:).number*SIunits(data({'v[2,z](0)'},:).unit{1});
            obj.v0(3,1)= data({'v[3,x](0)'},:).number*SIunits(data({'v[3,x](0)'},:).unit{1});
            obj.v0(3,2)= data({'v[3,y](0)'},:).number*SIunits(data({'v[3,y](0)'},:).unit{1});
            obj.v0(3,3)= data({'v[3,z](0)'},:).number*SIunits(data({'v[3,z](0)'},:).unit{1});
            
            obj.Tend   = data({'T[end]'   },:).number*SIunits(data({'T[end]'   },:).unit{1});

            % derived properties
            obj.theta(1) = obj.m(1)/obj.m(1);
            obj.theta(2) = obj.m(2)/obj.m(1);
            obj.theta(3) = obj.m(3)/obj.m(1);
            obj.M        = obj.m(1);  
            obj.F        = obj.G*obj.M^2/obj.L^2;  
            obj.T        = sqrt(obj.M*obj.L/obj.F);
            obj.tEnd     = obj.Tend/obj.T;
            
        end
        
        % no functions here 
                
    end
end

